@@ -17,9 +17,7 @@
 #include "drogon/utils/FunctionTraits.h"
 #include <json/value.h>
 
-namespace drogon
-{
-namespace plugin
+namespace drogon::plugin
 {
 /**
  * @brief The SlashRemover plugin redirects requests to proper paths if they
@@ -29,7 +27,7 @@ namespace plugin
  * @code
   {
      "name": "drogon::plugin::SlashRemover",
-     "dependencies": [],
+     "dependencies": ["drogon::plugin::Redirector"],
      "config": {
         // If true, it removes all trailing slashes, e.g.
 ///home// -> ///home
@@ -53,11 +51,11 @@ class DROGON_EXPORT SlashRemover : public drogon::Plugin<SlashRemover>
     SlashRemover()
     {
     }
+
     void initAndStart(const Json::Value &config) override;
     void shutdown() override;
 
   private:
     bool trailingSlashes_{true}, duplicateSlashes_{true}, redirect_{true};
 };
-}  // namespace plugin
-}  // namespace drogon
\ No newline at end of file
+}  // namespace drogon::plugin
