@@ -29,6 +29,7 @@
 #endif
 
 using namespace drogon;
+
 void HttpRequestImpl::parseJson() const
 {
     auto input = contentView();
@@ -70,12 +71,13 @@ void HttpRequestImpl::parseJson() const
             std::make_unique<std::string>("content type error");
     }
 }
+
 void HttpRequestImpl::parseParameters() const
 {
     auto input = queryView();
     if (!input.empty())
     {
-        string_view::size_type pos = 0;
+        std::string_view::size_type pos = 0;
         while ((input[pos] == '?' ||
                 isspace(static_cast<unsigned char>(input[pos]))) &&
                pos < input.length())
@@ -83,14 +85,14 @@ void HttpRequestImpl::parseParameters() const
             ++pos;
         }
         auto value = input.substr(pos);
-        while ((pos = value.find('&')) != string_view::npos)
+        while ((pos = value.find('&')) != std::string_view::npos)
         {
             auto coo = value.substr(0, pos);
             auto epos = coo.find('=');
-            if (epos != string_view::npos)
+            if (epos != std::string_view::npos)
             {
                 auto key = coo.substr(0, epos);
-                string_view::size_type cpos = 0;
+                std::string_view::size_type cpos = 0;
                 while (cpos < key.length() &&
                        isspace(static_cast<unsigned char>(key[cpos])))
                     ++cpos;
@@ -106,10 +108,10 @@ void HttpRequestImpl::parseParameters() const
         {
             auto &coo = value;
             auto epos = coo.find('=');
-            if (epos != string_view::npos)
+            if (epos != std::string_view::npos)
             {
                 auto key = coo.substr(0, epos);
-                string_view::size_type cpos = 0;
+                std::string_view::size_type cpos = 0;
                 while (cpos < key.length() &&
                        isspace(static_cast<unsigned char>(key[cpos])))
                     ++cpos;
@@ -132,7 +134,7 @@ void HttpRequestImpl::parseParameters() const
     if (type.empty() ||
         type.find("application/x-www-form-urlencoded") != std::string::npos)
     {
-        string_view::size_type pos = 0;
+        std::string_view::size_type pos = 0;
         while ((input[pos] == '?' ||
                 isspace(static_cast<unsigned char>(input[pos]))) &&
                pos < input.length())
@@ -140,14 +142,14 @@ void HttpRequestImpl::parseParameters() const
             ++pos;
         }
         auto value = input.substr(pos);
-        while ((pos = value.find('&')) != string_view::npos)
+        while ((pos = value.find('&')) != std::string_view::npos)
         {
             auto coo = value.substr(0, pos);
             auto epos = coo.find('=');
-            if (epos != string_view::npos)
+            if (epos != std::string_view::npos)
             {
                 auto key = coo.substr(0, epos);
-                string_view::size_type cpos = 0;
+                std::string_view::size_type cpos = 0;
                 while (cpos < key.length() &&
                        isspace(static_cast<unsigned char>(key[cpos])))
                     ++cpos;
@@ -163,10 +165,10 @@ void HttpRequestImpl::parseParameters() const
         {
             auto &coo = value;
             auto epos = coo.find('=');
-            if (epos != string_view::npos)
+            if (epos != std::string_view::npos)
             {
                 auto key = coo.substr(0, epos);
-                string_view::size_type cpos = 0;
+                std::string_view::size_type cpos = 0;
                 while (cpos < key.length() &&
                        isspace(static_cast<unsigned char>(key[cpos])))
                     ++cpos;
@@ -581,6 +583,7 @@ void HttpRequestImpl::swap(HttpRequestImpl &that) noexcept
     swap(loop_, that.loop_);
     swap(flagForParsingContentType_, that.flagForParsingContentType_);
     swap(jsonParsingErrorPtr_, that.jsonParsingErrorPtr_);
+    swap(routingParams_, that.routingParams_);
 }
 
 const char *HttpRequestImpl::versionString() const
@@ -637,7 +640,7 @@ const char *HttpRequestImpl::methodString() const
 bool HttpRequestImpl::setMethod(const char *start, const char *end)
 {
     assert(method_ == Invalid);
-    string_view m(start, end - start);
+    std::string_view m(start, end - start);
     switch (m.length())
     {
         case 3:
@@ -808,7 +811,7 @@ StreamDecompressStatus HttpRequestImpl::decompressBodyBrotli() noexcept
     auto minVal = [](size_t a, size_t b) { return a < b ? a : b; };
     std::unique_ptr<CacheFile> cacheFileHolder;
     std::string contentHolder;
-    string_view compressed;
+    std::string_view compressed;
     if (cacheFilePtr_)
     {
         cacheFileHolder = std::move(cacheFilePtr_);
@@ -880,7 +883,7 @@ StreamDecompressStatus HttpRequestImpl::decompressBodyGzip() noexcept
     auto minVal = [](size_t a, size_t b) { return a < b ? a : b; };
     std::unique_ptr<CacheFile> cacheFileHolder;
     std::string contentHolder;
-    string_view compressed;
+    std::string_view compressed;
     if (cacheFilePtr_)
     {
         cacheFileHolder = std::move(cacheFilePtr_);
