@@ -21,354 +21,354 @@ namespace drogon
 {
 static std::unordered_map<std::string, std::string> customMime;
 
-const string_view &statusCodeToString(int code)
+const std::string_view &statusCodeToString(int code)
 {
     switch (code)
     {
         case 100:
         {
-            static string_view sv = "Continue";
+            static std::string_view sv = "Continue";
             return sv;
         }
         case 101:
         {
-            static string_view sv = "Switching Protocols";
+            static std::string_view sv = "Switching Protocols";
             return sv;
         }
         case 102:
         {
-            static string_view sv = "Processing";
+            static std::string_view sv = "Processing";
             return sv;
         }
         case 103:
         {
-            static string_view sv = "Early Hints";
+            static std::string_view sv = "Early Hints";
             return sv;
         }
         case 200:
         {
-            static string_view sv = "OK";
+            static std::string_view sv = "OK";
             return sv;
         }
         case 201:
         {
-            static string_view sv = "Created";
+            static std::string_view sv = "Created";
             return sv;
         }
         case 202:
         {
-            static string_view sv = "Accepted";
+            static std::string_view sv = "Accepted";
             return sv;
         }
         case 203:
         {
-            static string_view sv = "Non-Authoritative Information";
+            static std::string_view sv = "Non-Authoritative Information";
             return sv;
         }
         case 204:
         {
-            static string_view sv = "No Content";
+            static std::string_view sv = "No Content";
             return sv;
         }
         case 205:
         {
-            static string_view sv = "Reset Content";
+            static std::string_view sv = "Reset Content";
             return sv;
         }
         case 206:
         {
-            static string_view sv = "Partial Content";
+            static std::string_view sv = "Partial Content";
             return sv;
         }
         case 207:
         {
-            static string_view sv = "Multi-Status";
+            static std::string_view sv = "Multi-Status";
             return sv;
         }
         case 208:
         {
-            static string_view sv = "Already Reported";
+            static std::string_view sv = "Already Reported";
             return sv;
         }
         case 226:
         {
-            static string_view sv = "IM Used";
+            static std::string_view sv = "IM Used";
             return sv;
         }
         case 300:
         {
-            static string_view sv = "Multiple Choices";
+            static std::string_view sv = "Multiple Choices";
             return sv;
         }
         case 301:
         {
-            static string_view sv = "Moved Permanently";
+            static std::string_view sv = "Moved Permanently";
             return sv;
         }
         case 302:
         {
-            static string_view sv = "Found";
+            static std::string_view sv = "Found";
             return sv;
         }
         case 303:
         {
-            static string_view sv = "See Other";
+            static std::string_view sv = "See Other";
             return sv;
         }
         case 304:
         {
-            static string_view sv = "Not Modified";
+            static std::string_view sv = "Not Modified";
             return sv;
         }
         case 305:
         {
-            static string_view sv = "Use Proxy";
+            static std::string_view sv = "Use Proxy";
             return sv;
         }
         case 306:
         {
-            static string_view sv = "(Unused)";
+            static std::string_view sv = "(Unused)";
             return sv;
         }
         case 307:
         {
-            static string_view sv = "Temporary Redirect";
+            static std::string_view sv = "Temporary Redirect";
             return sv;
         }
         case 308:
         {
-            static string_view sv = "Permanent Redirect";
+            static std::string_view sv = "Permanent Redirect";
             return sv;
         }
         case 400:
         {
-            static string_view sv = "Bad Request";
+            static std::string_view sv = "Bad Request";
             return sv;
         }
         case 401:
         {
-            static string_view sv = "Unauthorized";
+            static std::string_view sv = "Unauthorized";
             return sv;
         }
         case 402:
         {
-            static string_view sv = "Payment Required";
+            static std::string_view sv = "Payment Required";
             return sv;
         }
         case 403:
         {
-            static string_view sv = "Forbidden";
+            static std::string_view sv = "Forbidden";
             return sv;
         }
         case 404:
         {
-            static string_view sv = "Not Found";
+            static std::string_view sv = "Not Found";
             return sv;
         }
         case 405:
         {
-            static string_view sv = "Method Not Allowed";
+            static std::string_view sv = "Method Not Allowed";
             return sv;
         }
         case 406:
         {
-            static string_view sv = "Not Acceptable";
+            static std::string_view sv = "Not Acceptable";
             return sv;
         }
         case 407:
         {
-            static string_view sv = "Proxy Authentication Required";
+            static std::string_view sv = "Proxy Authentication Required";
             return sv;
         }
         case 408:
         {
-            static string_view sv = "Request Time-out";
+            static std::string_view sv = "Request Time-out";
             return sv;
         }
         case 409:
         {
-            static string_view sv = "Conflict";
+            static std::string_view sv = "Conflict";
             return sv;
         }
         case 410:
         {
-            static string_view sv = "Gone";
+            static std::string_view sv = "Gone";
             return sv;
         }
         case 411:
         {
-            static string_view sv = "Length Required";
+            static std::string_view sv = "Length Required";
             return sv;
         }
         case 412:
         {
-            static string_view sv = "Precondition Failed";
+            static std::string_view sv = "Precondition Failed";
             return sv;
         }
         case 413:
         {
-            static string_view sv = "Request Entity Too Large";
+            static std::string_view sv = "Request Entity Too Large";
             return sv;
         }
         case 414:
         {
-            static string_view sv = "Request-URI Too Large";
+            static std::string_view sv = "Request-URI Too Large";
             return sv;
         }
         case 415:
         {
-            static string_view sv = "Unsupported Media Type";
+            static std::string_view sv = "Unsupported Media Type";
             return sv;
         }
         case 416:
         {
-            static string_view sv = "Requested Range Not Satisfiable";
+            static std::string_view sv = "Requested Range Not Satisfiable";
             return sv;
         }
         case 417:
         {
-            static string_view sv = "Expectation Failed";
+            static std::string_view sv = "Expectation Failed";
             return sv;
         }
         case 418:
         {
-            static string_view sv = "I'm a Teapot";
+            static std::string_view sv = "I'm a Teapot";
             return sv;
         }
         case 421:
         {
-            static string_view sv = "Misdirected Request";
+            static std::string_view sv = "Misdirected Request";
             return sv;
         }
         case 422:
         {
-            static string_view sv = "Unprocessable Entity";
+            static std::string_view sv = "Unprocessable Entity";
             return sv;
         }
         case 423:
         {
-            static string_view sv = "Locked";
+            static std::string_view sv = "Locked";
             return sv;
         }
         case 424:
         {
-            static string_view sv = "Failed Dependency";
+            static std::string_view sv = "Failed Dependency";
             return sv;
         }
         case 425:
         {
-            static string_view sv = "Too Early";
+            static std::string_view sv = "Too Early";
             return sv;
         }
         case 426:
         {
-            static string_view sv = "Upgrade Required";
+            static std::string_view sv = "Upgrade Required";
             return sv;
         }
         case 428:
         {
-            static string_view sv = "Precondition Required";
+            static std::string_view sv = "Precondition Required";
             return sv;
         }
         case 429:
         {
-            static string_view sv = "Too Many Requests";
+            static std::string_view sv = "Too Many Requests";
             return sv;
         }
         case 431:
         {
-            static string_view sv = "Request Header Fields Too Large";
+            static std::string_view sv = "Request Header Fields Too Large";
             return sv;
         }
         case 451:
         {
-            static string_view sv = "Unavailable For Legal Reasons";
+            static std::string_view sv = "Unavailable For Legal Reasons";
             return sv;
         }
         case 500:
         {
-            static string_view sv = "Internal Server Error";
+            static std::string_view sv = "Internal Server Error";
             return sv;
         }
         case 501:
         {
-            static string_view sv = "Not Implemented";
+            static std::string_view sv = "Not Implemented";
             return sv;
         }
         case 502:
         {
-            static string_view sv = "Bad Gateway";
+            static std::string_view sv = "Bad Gateway";
             return sv;
         }
         case 503:
         {
-            static string_view sv = "Service Unavailable";
+            static std::string_view sv = "Service Unavailable";
             return sv;
         }
         case 504:
         {
-            static string_view sv = "Gateway Time-out";
+            static std::string_view sv = "Gateway Time-out";
             return sv;
         }
         case 505:
         {
-            static string_view sv = "HTTP Version Not Supported";
+            static std::string_view sv = "HTTP Version Not Supported";
             return sv;
         }
         case 506:
         {
-            static string_view sv = "Variant Also Negotiates";
+            static std::string_view sv = "Variant Also Negotiates";
             return sv;
         }
         case 507:
         {
-            static string_view sv = "Insufficient Storage";
+            static std::string_view sv = "Insufficient Storage";
             return sv;
         }
         case 508:
         {
-            static string_view sv = "Loop Detected";
+            static std::string_view sv = "Loop Detected";
             return sv;
         }
         case 510:
         {
-            static string_view sv = "Not Extended";
+            static std::string_view sv = "Not Extended";
             return sv;
         }
         case 511:
         {
-            static string_view sv = "Network Authentication Required";
+            static std::string_view sv = "Network Authentication Required";
             return sv;
         }
         default:
             if (code >= 100 && code < 200)
             {
-                static string_view sv = "Informational";
+                static std::string_view sv = "Informational";
                 return sv;
             }
             else if (code >= 200 && code < 300)
             {
-                static string_view sv = "Successful";
+                static std::string_view sv = "Successful";
                 return sv;
             }
             else if (code >= 300 && code < 400)
             {
-                static string_view sv = "Redirection";
+                static std::string_view sv = "Redirection";
                 return sv;
             }
             else if (code >= 400 && code < 500)
             {
-                static string_view sv = "Bad Request";
+                static std::string_view sv = "Bad Request";
                 return sv;
             }
             else if (code >= 500 && code < 600)
             {
-                static string_view sv = "Server Error";
+                static std::string_view sv = "Server Error";
                 return sv;
             }
             else
             {
-                static string_view sv = "Undefined Error";
+                static std::string_view sv = "Undefined Error";
                 return sv;
             }
     }
@@ -484,12 +484,9 @@ ContentType getContentType(const std::string &fileName)
     }
 }
 
-ContentType parseContentType(const string_view &contentType)
+ContentType parseContentType(const std::string_view &contentType)
 {
-    // When using C++14. boost::string_view have a different idea of hashing.
-    // For boost. only string_view referencing the same underlying string and
-    // range have the same hash. Use a custom hash to avoid it
-    static const std::unordered_map<string_view, ContentType> map_{
+    static const std::unordered_map<std::string_view, ContentType> map_{
         {"text/html", CT_TEXT_HTML},
         {"application/x-www-form-urlencoded", CT_APPLICATION_X_FORM},
         {"application/xml", CT_APPLICATION_XML},
@@ -524,10 +521,10 @@ ContentType parseContentType(const string_view &contentType)
     return iter->second;
 }
 
-FileType parseFileType(const string_view &fileExtension)
+FileType parseFileType(const std::string_view &fileExtension)
 {
     // https://en.wikipedia.org/wiki/List_of_file_formats
-    static const std::unordered_map<string_view, FileType> map_{
+    static const std::unordered_map<std::string_view, FileType> map_{
         {"", FT_UNKNOWN},    {"html", FT_DOCUMENT}, {"docx", FT_DOCUMENT},
         {"zip", FT_ARCHIVE}, {"rar", FT_ARCHIVE},   {"xz", FT_ARCHIVE},
         {"7z", FT_ARCHIVE},  {"tgz", FT_ARCHIVE},   {"gz", FT_ARCHIVE},
@@ -541,149 +538,150 @@ FileType parseFileType(const string_view &fileExtension)
     return iter->second;
 }
 
-const string_view &contentTypeToMime(ContentType contenttype)
+const std::string_view &contentTypeToMime(ContentType contenttype)
 {
     switch (contenttype)
     {
         case CT_TEXT_HTML:
         {
-            static string_view sv = "text/html; charset=utf-8";
+            static std::string_view sv = "text/html; charset=utf-8";
             return sv;
         }
         case CT_APPLICATION_X_FORM:
         {
-            static string_view sv = "application/x-www-form-urlencoded";
+            static std::string_view sv = "application/x-www-form-urlencoded";
             return sv;
         }
         case CT_APPLICATION_XML:
         {
-            static string_view sv = "application/xml; charset=utf-8";
+            static std::string_view sv = "application/xml; charset=utf-8";
             return sv;
         }
         case CT_APPLICATION_JSON:
         {
-            static string_view sv = "application/json; charset=utf-8";
+            static std::string_view sv = "application/json; charset=utf-8";
             return sv;
         }
         case CT_APPLICATION_X_JAVASCRIPT:
         {
-            static string_view sv = "application/x-javascript; charset=utf-8";
+            static std::string_view sv =
+                "application/x-javascript; charset=utf-8";
             return sv;
         }
         case CT_TEXT_JAVASCRIPT:
         {
-            static string_view sv = "text/javascript; charset=utf-8";
+            static std::string_view sv = "text/javascript; charset=utf-8";
             return sv;
         }
         case CT_TEXT_CSS:
         {
-            static string_view sv = "text/css; charset=utf-8";
+            static std::string_view sv = "text/css; charset=utf-8";
             return sv;
         }
         case CT_TEXT_XML:
         {
-            static string_view sv = "text/xml; charset=utf-8";
+            static std::string_view sv = "text/xml; charset=utf-8";
             return sv;
         }
         case CT_TEXT_XSL:
         {
-            static string_view sv = "text/xsl; charset=utf-8";
+            static std::string_view sv = "text/xsl; charset=utf-8";
             return sv;
         }
         case CT_APPLICATION_OCTET_STREAM:
         {
-            static string_view sv = "application/octet-stream";
+            static std::string_view sv = "application/octet-stream";
             return sv;
         }
         case CT_IMAGE_SVG_XML:
         {
-            static string_view sv = "image/svg+xml";
+            static std::string_view sv = "image/svg+xml";
             return sv;
         }
         case CT_APPLICATION_X_FONT_TRUETYPE:
         {
-            static string_view sv = "application/x-font-truetype";
+            static std::string_view sv = "application/x-font-truetype";
             return sv;
         }
         case CT_APPLICATION_X_FONT_OPENTYPE:
         {
-            static string_view sv = "application/x-font-opentype";
+            static std::string_view sv = "application/x-font-opentype";
             return sv;
         }
         case CT_APPLICATION_FONT_WOFF:
         {
-            static string_view sv = "application/font-woff";
+            static std::string_view sv = "application/font-woff";
             return sv;
         }
         case CT_APPLICATION_FONT_WOFF2:
         {
-            static string_view sv = "application/font-woff2";
+            static std::string_view sv = "application/font-woff2";
             return sv;
         }
         case CT_APPLICATION_VND_MS_FONTOBJ:
         {
-            static string_view sv = "application/vnd.ms-fontobject";
+            static std::string_view sv = "application/vnd.ms-fontobject";
             return sv;
         }
         case CT_APPLICATION_PDF:
         {
-            static string_view sv = "application/pdf";
+            static std::string_view sv = "application/pdf";
             return sv;
         }
         case CT_IMAGE_PNG:
         {
-            static string_view sv = "image/png";
+            static std::string_view sv = "image/png";
             return sv;
         }
         case CT_IMAGE_AVIF:
         {
-            static string_view sv = "image/avif";
+            static std::string_view sv = "image/avif";
             return sv;
         }
         case CT_IMAGE_WEBP:
         {
-            static string_view sv = "image/webp";
+            static std::string_view sv = "image/webp";
             return sv;
         }
         case CT_IMAGE_JPG:
         {
-            static string_view sv = "image/jpeg";
+            static std::string_view sv = "image/jpeg";
             return sv;
         }
         case CT_IMAGE_GIF:
         {
-            static string_view sv = "image/gif";
+            static std::string_view sv = "image/gif";
             return sv;
         }
         case CT_IMAGE_XICON:
         {
-            static string_view sv = "image/x-icon";
+            static std::string_view sv = "image/x-icon";
             return sv;
         }
         case CT_IMAGE_BMP:
         {
-            static string_view sv = "image/bmp";
+            static std::string_view sv = "image/bmp";
             return sv;
         }
         case CT_IMAGE_ICNS:
         {
-            static string_view sv = "image/icns";
+            static std::string_view sv = "image/icns";
             return sv;
         }
         case CT_APPLICATION_WASM:
         {
-            static string_view sv = "application/wasm";
+            static std::string_view sv = "application/wasm";
             return sv;
         }
         case CT_NONE:
         {
-            static string_view sv = "";
+            static std::string_view sv = "";
             return sv;
         }
         default:
         case CT_TEXT_PLAIN:
         {
-            static string_view sv = "text/plain; charset=utf-8";
+            static std::string_view sv = "text/plain; charset=utf-8";
             return sv;
         }
     }
@@ -703,7 +701,7 @@ void registerCustomExtensionMime(const std::string &ext,
     mimeStr = mime;
 }
 
-const string_view fileNameToMime(const std::string &fileName)
+const std::string_view fileNameToMime(const std::string &fileName)
 {
     ContentType intenalContentType = getContentType(fileName);
     if (intenalContentType != CT_APPLICATION_OCTET_STREAM)
@@ -724,7 +722,8 @@ const string_view fileNameToMime(const std::string &fileName)
         return "";
     return it->second;
 }
-std::pair<ContentType, const string_view> fileNameToContentTypeAndMime(
+
+std::pair<ContentType, const std::string_view> fileNameToContentTypeAndMime(
     const std::string &fileName)
 {
     ContentType intenalContentType = getContentType(fileName);
