@@ -123,7 +123,7 @@ void DbClientLockFree::execSql(
                 (transSet_.empty() || transSet_.find(conn) == transSet_.end()))
             {
                 conn->execSql(
-                    string_view{sql, sqlLength},
+                    std::string_view{sql, sqlLength},
                     paraNum,
                     std::move(parameters),
                     std::move(length),
@@ -153,7 +153,7 @@ void DbClientLockFree::execSql(
                      transSet_.find(conn) == transSet_.end()))
                 {
                     conn->execSql(
-                        string_view{sql, sqlLength},
+                        std::string_view{sql, sqlLength},
                         paraNum,
                         std::move(parameters),
                         std::move(length),
@@ -185,7 +185,7 @@ void DbClientLockFree::execSql(
                 if (transSet_.empty() ||
                     transSet_.find(conn) == transSet_.end())
                 {
-                    conn->execSql(string_view{sql, sqlLength},
+                    conn->execSql(std::string_view{sql, sqlLength},
                                   paraNum,
                                   std::move(parameters),
                                   std::move(length),
@@ -211,7 +211,7 @@ void DbClientLockFree::execSql(
 
     // LOG_TRACE << "Push query to buffer";
     sqlCmdBuffer_.emplace_back(std::make_shared<SqlCmd>(
-        string_view{sql, sqlLength},
+        std::string_view{sql, sqlLength},
         paraNum,
         std::move(parameters),
         std::move(length),
@@ -554,7 +554,7 @@ void DbClientLockFree::execSqlWithTimeout(
                 (transSet_.empty() || transSet_.find(conn) == transSet_.end()))
             {
                 conn->execSql(
-                    string_view{sql, sqlLength},
+                    std::string_view{sql, sqlLength},
                     paraNum,
                     std::move(parameters),
                     std::move(length),
@@ -587,7 +587,7 @@ void DbClientLockFree::execSqlWithTimeout(
                      transSet_.find(conn) == transSet_.end()))
                 {
                     conn->execSql(
-                        string_view{sql, sqlLength},
+                        std::string_view{sql, sqlLength},
                         paraNum,
                         std::move(parameters),
                         std::move(length),
@@ -622,7 +622,7 @@ void DbClientLockFree::execSqlWithTimeout(
                 if (transSet_.empty() ||
                     transSet_.find(conn) == transSet_.end())
                 {
-                    conn->execSql(string_view{sql, sqlLength},
+                    conn->execSql(std::string_view{sql, sqlLength},
                                   paraNum,
                                   std::move(parameters),
                                   std::move(length),
@@ -648,7 +648,7 @@ void DbClientLockFree::execSqlWithTimeout(
 
     // LOG_TRACE << "Push query to buffer";
     auto cmdPtr = std::make_shared<SqlCmd>(
-        string_view{sql, sqlLength},
+        std::string_view{sql, sqlLength},
         paraNum,
         std::move(parameters),
         std::move(length),
